@@ -66,8 +66,8 @@ import sys
 import warnings
 
 if 'sphinx' in sys.modules:
-    setattr(sys, 'is_epydoc', True)
-_is_epydoc = hasattr(sys, 'is_epydoc') and sys.is_epydoc
+    setattr(sys, 'is_pyglet_docgen', True)
+_is_pyglet_docgen = hasattr(sys, 'is_pyglet_docgen') and sys.is_pyglet_docgen
 
 #: The release version of this pyglet installation.
 #:
@@ -81,7 +81,7 @@ _is_epydoc = hasattr(sys, 'is_epydoc') and sys.is_epydoc
 #:    >>> parse_version(pyglet.version) >= parse_version('1.1')
 #:    True
 #:
-version = '1.3.0'
+version = '1.3.1'
 
 # Pyglet platform treats *BSD systems as Linux
 compat_platform = sys.platform
